@@ -59,7 +59,7 @@ def usage():
 
         Options include:
         -d|--debug      Catch exceptions thrown by the program.
-        -h|--help       Print this documenation and exit.
+        -h|--help       Print this documentation and exit.
         -n|--noauth     Allow packages from unathenticated archives.
         -q|--quiet	Do not show progress of commands.
         -s|--simulate   Show commands to be executed but don't execute.
@@ -127,6 +127,8 @@ Run LIST-COMMANDS for a complete list of commands.
  dist-upgrade   Upgrade to new distribution (installed and new rqd packages)
  docs           Equivalent to help with -verbose=2
  download       Download package files ready for an install
+ editsources    Edit the list of archives for Debian packages
+ extract        Extract the files from a package file to a directory
  file-download  Download packages listed in file ready for an install
  file-install   Install packages listed in a file
  file-remove    Remove packages listed in a file
@@ -180,6 +182,7 @@ Run LIST-COMMANDS for a complete list of commands.
  purge          Remove one or more packages and configuration files
  purge-depend   Purge package and those it depend on and not required by others
  purge-orphans  Purge orphaned libraries (not required by installed packages)
+ purge-removed  Purge all packages marked as deinstall
  readme         Display the package's README file from /usr/share/doc
  recursive      Download package and any packages it depends on
  recommended    Install package and associated recommended packages
