@@ -366,7 +366,7 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "autoinstall":
         if requires_args(command, args, "a list of package names"):
-            command = "apt-get install --assume-yes " +\
+            command = "apt-get install --assume-yes " + noauth + " " +\
                       perform.concat(args[1:])
             perform.execute(command, root=1)
 
@@ -378,7 +378,7 @@ def select_command(command, args, verbose, teaching):
         if requires_args(command, args, "a list of packages"):
             perform.execute("apt-cache policy " + perform.concat(args[1:]))
 
-    elif command == "bug" or command == "bugs":
+    elif command == "bug" or command == "bugs" or command == "reportbug":
         if requires_one_arg(command, args, "a single named package"):
             if requires_package("reportbug", "/usr/bin/reportbug"):
                 perform.execute("reportbug " + args[1])
@@ -781,6 +781,15 @@ def select_command(command, args, verbose, teaching):
                     pkgs += " " + p.strip()
                 if pkgs: perform.execute("apt-get remove --purge" + pkgs, root=1)
 
+    elif command == "purgeremoved":
+        if requires_no_args(command, args):
+            pkgs = ""
+            cmd = "dpkg-query -W --showformat='${Package}\t${Status}\n' | " +\
+                "grep \"deinstall ok config-files\" | cut -f 1 "
+            for p in perform.execute(cmd, pipe=True):
+                pkgs += " " + p.strip()
+            if pkgs: perform.execute("apt-get remove --purge" + pkgs, root=1)
+
     elif command == "readme":
         if requires_one_arg(command, args, "a single package"):
             docpath = "/usr/share/doc/" + args[1] + "/"
